@@ -1,36 +1,23 @@
-/* $Id: air_coil_gui.c,v 1.18 2005/10/29 19:07:29 dan Exp $ */
+/* $Id: air_coil_gui.c,v 1.23 2009/02/06 23:02:28 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
@@ -51,11 +38,16 @@
 #include "misc.h"
 #include "units.h"
 
+#if GTK_CHECK_VERSION(2,10,0)
+#include "pixmaps/figure_air_coil.h"
+#endif
 #include "air_coil.h"
 #include "air_coil_gui.h"
 #include "air_coil_loadsave.h"
+#include "newprint.h"
 #include "physconst.h"
 
+#include "symbols.h"
 #include "gtk-units.h"
 #include "wcalc.h"
 
@@ -64,6 +56,7 @@
 #endif
 
 static void print_ps(Wcalc *wcalc,FILE *fp);
+static GList * dump_values(Wcalc *wcalc);
 
 static void use_len_pressed(GtkWidget *widget, gpointer data );
 static void use_fill_pressed(GtkWidget *widget, gpointer data );
@@ -119,6 +112,7 @@ air_coil_gui *air_coil_gui_new(void)
   wcalc->analyze = NULL;
   wcalc->synthesize = NULL;
   wcalc->display = NULL;
+  wcalc->dump_values = dump_values;
 
   wcalc->file_name=NULL;
   wcalc->file_basename=NULL;
@@ -753,10 +747,13 @@ static void calculate( air_coil_gui *gui, GtkWidget *w, gpointer data )
    * if the calculation completed with no errors, then clear the
    * "values out of sync" field
    */
-  if (rslt==0)
+  if (rslt==0) {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "");
-  else
-    gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), _("Values out of\nrange."));
+    WC_WCALC(gui)->values_in_sync = TRUE;
+  } else {
+    gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "Values out of\nrange.");
+    WC_WCALC(gui)->values_in_sync = FALSE;
+  }
 
 }
 
@@ -869,6 +866,49 @@ static void gui_save(Wcalc *wcalc, FILE *fp, char *name)
   air_coil_save(WC_AIR_COIL_GUI(wcalc)->coil,fp,name);
 }
 
+static GList * dump_values(Wcalc *wcalc)
+{
+  static GList * list = NULL;
+#if GTK_CHECK_VERSION(2,10,0)
+  air_coil_gui *gui;
+  air_coil_coil * c;
+
+  gui = WC_AIR_COIL_GUI(wcalc);
+  c = gui->coil;
+
+  /* Initialize the graphics */
+  if( list == NULL ) {
+    figure_air_coil_init();
+  }  {
+    // FIXME -- free the old list first!!!!
+    list = NULL;
+    list = wc_print_add_cairo(figure_air_coil_render[0], 
+			      figure_air_coil_width[0], figure_air_coil_height[0], list);
+    
+    list = wc_print_add_double("Number of turns (N)", c->Nf, NULL, list);
+    list = wc_print_add_double("Length of coil (Len)", c->len, c->units_len, list);
+    list = wc_print_add_double("Wire gauge (AWG)", c->AWGf, NULL, list);
+    list = wc_print_add_double("Fill (ratio of length to minimum length)", c->fill, NULL, list);
+
+    list = wc_print_add_double("Wire resistivity ("
+			       WC_SYM_RHO_LC ")", c->rho, c->units_rho, list);
+
+    list = wc_print_add_double("Inside diameter of coil (I.D.)", c->dia, c->units_dia, list);
+
+
+    list = wc_print_add_double("Coil inductance (L)", c->L, c->units_L, list);
+    list = wc_print_add_double("Coil maximum (closewound) inductance (Lmax)", c->Lmax, 
+			       c->units_L, list);
+
+    list = wc_print_add_double("Analysis frequency", c->freq, c->units_freq, list);
+    list = wc_print_add_double("Coil quality factor (Q)", c->Q, NULL, list);
+    list = wc_print_add_double("Self resonant frequency", c->SRF, c->units_SRF, list);
+
+
+  }
+#endif
+  return list;
+}
 
 static void print_ps(Wcalc *wcalc, FILE *fp)
 {
