@@ -1,36 +1,23 @@
-/* $Id: coax_gui.c,v 1.32 2005/10/29 19:07:30 dan Exp $ */
+/* $Id: coax_gui.c,v 1.39 2009/02/14 02:09:54 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
@@ -51,11 +38,16 @@
 #include "gtk-units.h"
 
 #include "misc.h"
+#include "symbols.h"
 #include "units.h"
 
+#if GTK_CHECK_VERSION(2,10,0)
+#include "pixmaps/figure_coax.h"
+#endif
 #include "coax.h"
 #include "coax_gui.h"
 #include "coax_loadsave.h"
+#include "newprint.h"
 #include "physconst.h"
 
 #include "wcalc.h"
@@ -65,6 +57,7 @@
 #endif
 
 static void print_ps(Wcalc *wcalc,FILE *fp);
+static GList * dump_values(Wcalc *wcalc);
 
 static void analyze( GtkWidget *w, gpointer data );
 static void synthesize_a( GtkWidget *w, gpointer data );
@@ -119,6 +112,7 @@ coax_gui *coax_gui_new(void)
   wcalc->analyze = NULL;
   wcalc->synthesize = NULL;
   wcalc->display = NULL;
+  wcalc->dump_values = dump_values;
 
   wcalc->file_name=NULL;
   wcalc->file_basename=NULL;
@@ -1046,10 +1040,13 @@ static void calculate( coax_gui *gui, GtkWidget *w, gpointer data )
    * if the calculation completed with no errors, then clear the
    * "values out of sync" field
    */
-  if (rslt==0)
+  if (rslt==0) {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "");
-  else
-    gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), _("Values out of\nrange."));
+    WC_WCALC(gui)->values_in_sync = TRUE;
+  } else {
+    gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "Values out of\nrange.");
+    WC_WCALC(gui)->values_in_sync = FALSE;
+  }
 
 }
 
@@ -1188,6 +1185,67 @@ static void gui_save(Wcalc *wcalc, FILE *fp, char *name)
   coax_save(WC_COAX_GUI(wcalc)->line,fp,name);
 }
 
+static GList * dump_values(Wcalc *wcalc)
+{
+  static GList * list = NULL;
+#if GTK_CHECK_VERSION(2,10,0)
+  coax_gui *gui;
+  coax_line *l;
+
+  gui = WC_COAX_GUI(wcalc);
+  l = gui->line;
+
+  /* Initialize the graphics */
+  if( list == NULL ) {
+    figure_coax_init();
+  }  {
+    // FIXME -- free the old list first!!!!
+    list = NULL;
+    list = wc_print_add_cairo(figure_coax_render[0], figure_coax_width[0], 
+			      figure_coax_height[0], list);
+
+    list = wc_print_add_double("Radius of inner conductor (a)", l->a, l->units_abct, list);
+    list = wc_print_add_double("Diameter of inner conductor (2a)", 2.0*l->a, l->units_abct, list);
+    list = wc_print_add_double("Inside radius of outer conductor (b)", l->b, l->units_abct, list);
+    list = wc_print_add_double("Inside diameter of outer conductor (2b)", 2.0*l->b, l->units_abct, list);
+    list = wc_print_add_double("Center conductor offset (c)", l->c, l->units_abct, list);
+    list = wc_print_add_double("Shield thickness (t)", l->tshield, l->units_abct, list);
+    list = wc_print_add_double("Line physical length (len)", l->len, l->units_abct, list);
+
+    list = wc_print_add_double("Center conductor resistivity (" WC_SYM_RHO_LC "<sub>a</sub>)", 
+			       l->rho_a, l->units_rho, list);
+
+    list = wc_print_add_double("Shield conductor resistivity (" WC_SYM_RHO_LC "<sub>b</sub>)", 
+			       l->rho_b, l->units_rho, list);
+    list = wc_print_add_double("Relative dielectric contant (" WC_SYM_EPSILON_LC "<sub>r</sub>)", l->er, NULL, list);
+    list = wc_print_add_double("Dielectric loss tangent (tan" WC_SYM_DELTA_UC ")", l->tand, NULL, list);
+
+    list = wc_print_add_double("Dielectric breakdown field strength (E<sub>max</sub>)", 
+			       l->emax, l->units_emax, list);
+
+    list = wc_print_add_double("Analysis Frequency", l->freq, l->units_freq, list);
+
+    list = wc_print_add_double("Characteristic Impedance", l->z0, NULL, list);
+    list = wc_print_add_double("Electrical length", l->elen, l->units_len, list);
+    list = wc_print_add_double("Delay", l->delay, l->units_delay, list);
+
+    list = wc_print_add_double("TE<sub>10</sub> mode cutoff frequency", l->fc, l->units_fc, list);
+
+    list = wc_print_add_double("Conductor loss", l->alpha_c, l->units_loss, list);
+    list = wc_print_add_double("Dielectric loss", l->alpha_d, l->units_loss, list);
+    list = wc_print_add_double("Total loss", l->loss, l->units_loss, list);
+    list = wc_print_add_double("Total loss per length", l->losslen, l->units_losslen, list);
+     
+    list = wc_print_add_double("Incremental Inductance", l->L, l->units_L, list);
+    list = wc_print_add_double("Incremental Capacitance", l->C, l->units_C, list);
+    list = wc_print_add_double("Incremental Resistance", l->R, l->units_R, list);
+    list = wc_print_add_double("Incremental Conductance", l->G, l->units_G, list);
+    
+  }
+#endif
+
+  return list;
+}
 
 static void print_ps(Wcalc *wcalc, FILE *fp)
 {
@@ -1237,7 +1295,7 @@ static void print_ps(Wcalc *wcalc, FILE *fp)
 	  gui->line->er);
   fprintf(fp,"(tan) show (d) symbolshow tab1 (=) show tab2 (" WC_FMT_G ") show newline\n",
 	  gui->line->tand);
-  fprintf(fp,"(r) symbolshow (a) subshow tab1 (=) show tab2 (" WC_FMT_G " %s) show newline\n",
+  fprintf(fp,"(p) symbolshow (a) subshow tab1 (=) show tab2 (" WC_FMT_G " %s) show newline\n",
 	  gui->line->rho_a/gui->line->units_rho->sf, gui->line->units_rho->name);
   fprintf(fp,"(r) symbolshow (b) subshow tab1 (=) show tab2 (" WC_FMT_G " %s) show newline\n",
 	  gui->line->rho_b/gui->line->units_rho->sf, gui->line->units_rho->name);
