@@ -1,36 +1,23 @@
-/* $Id: coupled_microstrip_gui.c,v 1.11 2005/10/12 18:12:02 dan Exp $ */
+/* $Id: coupled_microstrip_gui.c,v 1.17 2009/02/06 23:02:32 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2004, 2005 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2004, 2005, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
@@ -50,12 +37,17 @@
 #include "menus.h"
 #include "misc.h"
 
+#if GTK_CHECK_VERSION(2,10,0)
+#include "pixmaps/figure_coupled_microstrip.h"
+#endif
 #include "coupled_microstrip.h"
 #include "coupled_microstrip_gui.h"
 #include "coupled_microstrip_loadsave.h"
+#include "newprint.h"
 #include "physconst.h"
 #include "units.h"
 
+#include "symbols.h"
 #include "gtk-units.h"
 #include "wcalc.h"
 
@@ -67,6 +59,7 @@ static void use_z0k_pressed(GtkWidget *widget, gpointer data );
 static void use_z0ez0o_pressed(GtkWidget *widget, gpointer data );
 
 static void print_ps(Wcalc *wcalc,FILE *fp);
+static GList * dump_values(Wcalc *wcalc);
 
 static void analyze( GtkWidget *w, gpointer data );
 static void synthesize( GtkWidget *w, gpointer data );
@@ -116,6 +109,7 @@ coupled_microstrip_gui *coupled_microstrip_gui_new(void)
   wcalc->analyze = NULL;
   wcalc->synthesize = NULL;
   wcalc->display = NULL;
+  wcalc->dump_values = dump_values;
 
   wcalc->file_name=NULL;
   wcalc->file_basename=NULL;
@@ -290,7 +284,7 @@ static void values_init(coupled_microstrip_gui *gui, GtkWidget *parent)
 
   y++;
 
-  /* ---------------- Width  -------------- */
+  /* ---------------- Spacing  -------------- */
 
   text = gtk_label_new( "Spacing (S)" );
   gtk_table_attach(GTK_TABLE(table), text, x, x+1, y, y+1, 
@@ -1272,10 +1266,13 @@ static void calculate( coupled_microstrip_gui *gui, GtkWidget *w, gpointer data
    * if the calculation completed with no errors, then clear the
    * "values out of sync" field
    */
-  if (rslt==0)
+  if (rslt==0) {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "");
-  else
+    WC_WCALC(gui)->values_in_sync = TRUE;
+  } else {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "Values out of\nrange.");
+    WC_WCALC(gui)->values_in_sync = FALSE;
+  }
 
 }
 
@@ -1477,6 +1474,74 @@ static void gui_save(Wcalc *wcalc, FILE *fp, char *name)
   coupled_microstrip_save(WC_COUPLED_MICROSTRIP_GUI(wcalc)->line,fp,name);
 }
 
+static GList * dump_values(Wcalc *wcalc)
+{
+  static GList * list = NULL;
+#if GTK_CHECK_VERSION(2,10,0)
+  coupled_microstrip_gui *gui;
+  coupled_microstrip_line *l;
+
+  gui = WC_COUPLED_MICROSTRIP_GUI(wcalc);
+  l = gui->line;
+
+  /* Initialize the graphics */
+  if( list == NULL ) {
+    figure_coupled_microstrip_init();
+  }  {
+    // FIXME -- free the old list first!!!!
+    list = NULL;
+    list = wc_print_add_cairo(figure_coupled_microstrip_render[0], figure_coupled_microstrip_width[0], 
+			      figure_coupled_microstrip_height[0], list);
+
+    list = wc_print_add_double("Width of lines (W)", l->w, l->units_lwst, list);
+    list = wc_print_add_double("Length of lines (L)", l->l, l->units_lwst, list);
+    list = wc_print_add_double("Gap between lines (S)", l->s, l->units_lwst, list);
+
+    list = wc_print_add_double("Dielectric thickness (H)", l->subs->h, l->units_lwst, list);
+    list = wc_print_add_double("Relative dielectric contant ("
+			       WC_SYM_EPSILON_LC "<sub>r</sub>)", l->subs->er, NULL, list);
+    list = wc_print_add_double("Dielectric loss tangent (tan"
+			       WC_SYM_DELTA_LC ")", l->subs->tand, NULL, list);
+    list = wc_print_add_double("Metal thickness (t<sub>met</sub>)", l->subs->tmet, l->units_lwst, list);
+    list = wc_print_add_double("Metal resistivity ("
+			       WC_SYM_RHO_LC ")", l->subs->rho, l->units_rho, list);
+    list = wc_print_add_double("Metal surface roughness (rough)", l->subs->rough, 
+			       l->units_rough, list);
+
+    list = wc_print_add_double("Analysis Frequency", l->freq, l->units_freq, list);
+
+    list = wc_print_add_double("Characteristic Impedance", l->z0, NULL, list);
+    list = wc_print_add_double("Coupling coefficient", l->k, NULL, list);
+    list = wc_print_add_double("Even mode impedance", l->z0e, NULL, list);
+    list = wc_print_add_double("Odd mode impedance", l->z0o, NULL, list);
+
+    list = wc_print_add_double("Electrical length", l->len, NULL, list);
+
+    list = wc_print_add_double("Even mode loss", l->loss_ev, l->units_loss, list);
+    list = wc_print_add_double("Odd mode loss", l->loss_odd, l->units_loss, list);
+    list = wc_print_add_double("Even mode loss per length", l->losslen_ev, l->units_losslen, list);
+    list = wc_print_add_double("Odd mode loss per length", l->losslen_odd, l->units_losslen, list);
+
+    list = wc_print_add_double("Even mode open end length correction",
+			       l->deltale, l->units_deltal, list);
+    list = wc_print_add_double("Odd mode open end length correction",
+			       l->deltalo, l->units_deltal, list);
+     
+    list = wc_print_add_double("Even mode incremental Inductance", l->Lev, l->units_L, list);
+    list = wc_print_add_double("Even mode incremental Capacitance", l->Cev, l->units_C, list);
+    list = wc_print_add_double("Even mode incremental Resistance", l->Rev, l->units_R, list);
+    list = wc_print_add_double("Even mode incremental Conductance", l->Gev, l->units_G, list);
+
+    list = wc_print_add_double("Odd mode incremental Inductance", l->Lodd, l->units_L, list);
+    list = wc_print_add_double("Odd mode incremental Capacitance", l->Codd, l->units_C, list);
+    list = wc_print_add_double("Odd mode incremental Resistance", l->Rodd, l->units_R, list);
+    list = wc_print_add_double("Odd mode incremental Conductance", l->Godd, l->units_G, list);
+    
+  }
+#endif
+
+  return list;
+}
 
 static void print_ps(Wcalc *wcalc, FILE *fp)
 {
