@@ -1,36 +1,23 @@
-/* $Id: ic_microstrip_gui.c,v 1.14 2005/10/29 19:07:31 dan Exp $ */
+/* $Id: ic_microstrip_gui.c,v 1.19 2009/02/06 23:02:34 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2004, 2005 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2004, 2005 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
@@ -51,11 +38,16 @@
 #include "misc.h"
 #include "units.h"
 
+#if GTK_CHECK_VERSION(2,10,0)
+#include "pixmaps/figure_ic_microstrip.h"
+#endif
 #include "ic_microstrip.h"
 #include "ic_microstrip_gui.h"
 #include "ic_microstrip_loadsave.h"
+#include "newprint.h"
 #include "physconst.h"
 
+#include "symbols.h"
 #include "gtk-units.h"
 #include "wcalc.h"
 
@@ -64,6 +56,7 @@
 #endif
 
 static void print_ps(Wcalc *wcalc,FILE *fp);
+static GList * dump_values(Wcalc *wcalc);
 
 static void analyze( GtkWidget *w, gpointer data );
 static void synthesize_w( GtkWidget *w, gpointer data );
@@ -115,6 +108,7 @@ ic_microstrip_gui *ic_microstrip_gui_new(void)
   wcalc->analyze = NULL;
   wcalc->synthesize = NULL;
   wcalc->display = NULL;
+  wcalc->dump_values = dump_values;
 
   wcalc->file_name=NULL;
   wcalc->file_basename=NULL;
@@ -959,10 +953,13 @@ static void calculate( ic_microstrip_gui *gui, GtkWidget *w, gpointer data )
    * if the calculation completed with no errors, then clear the
    * "values out of sync" field
    */
-  if (rslt==0)
+  if (rslt==0) {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "");
-  else
+    WC_WCALC(gui)->values_in_sync = TRUE;
+  } else {
     gtk_label_set_text(GTK_LABEL(WC_WCALC(gui)->text_status), "Values out of\nrange.");
+    WC_WCALC(gui)->values_in_sync = FALSE;
+  }
 
 }
 
@@ -1109,6 +1106,71 @@ static void gui_save(Wcalc *wcalc, FILE *fp, char *name)
   ic_microstrip_save(WC_IC_MICROSTRIP_GUI(wcalc)->line,fp,name);
 }
 
+static GList * dump_values(Wcalc *wcalc)
+{
+  static GList * list = NULL;
+#if GTK_CHECK_VERSION(2,10,0)
+  ic_microstrip_gui *gui;
+  ic_microstrip_line *l;
+
+  gui = WC_IC_MICROSTRIP_GUI(wcalc);
+  l = gui->line;
+
+  /* Initialize the graphics */
+  if( list == NULL ) {
+    figure_ic_microstrip_init();
+  } {
+    // FIXME -- free the old list first!!!!
+    list = NULL;
+    list = wc_print_add_cairo(figure_ic_microstrip_render[0], figure_ic_microstrip_width[0], 
+			      figure_ic_microstrip_height[0], list);
+
+    list = wc_print_add_double("Width of line (w)", l->w, l->units_lwht, list);
+    list = wc_print_add_double("Length of line (l)", l->l, l->units_lwht, list);
+
+    list = wc_print_add_double("Oxide thickness (t<sub>ox</sub>)", l->subs->tox, l->units_lwht, list);
+    list = wc_print_add_double("Oxide relative dielectric contant ("
+			       WC_SYM_EPSILON_LC "<sub>ox</sub>)", l->subs->eox, NULL, list);
+
+    list = wc_print_add_double("Substrate thickness (h)", l->subs->h, l->units_lwht, list);
+    list = wc_print_add_double("Substrate relative dielectric contant ("
+			       WC_SYM_EPSILON_LC "<sub>s</sub>)", 
+			       l->subs->es, NULL, list);
+    list = wc_print_add_double("Substrate conductivity ("
+			       WC_SYM_SIGMA_LC "<sub>s</sub>)", 
+			       l->subs->sigmas, l->units_sigmas, list);
+
+    list = wc_print_add_double("Metal thickness (t<sub>met</sub>)", l->subs->tmet, l->units_lwht, list);
+    list = wc_print_add_double("Metal resistivity ("
+			       WC_SYM_RHO_LC ")", l->subs->rho, l->units_rho, list);
+    list = wc_print_add_double("Metal surface roughness (rough)", l->subs->rough, 
+			       l->units_rough, list);
+
+    list = wc_print_add_double("Analysis Frequency", l->freq, l->units_freq, list);
+
+    list = wc_print_add_double("Characteristic Impedance (real part)", l->Ro, NULL, list);
+    list = wc_print_add_double("Characteristic Impedance (imaginary part)", l->Xo, NULL, list);
+    list = wc_print_add_double("Electrical length", l->len, NULL, list);
+    list = wc_print_add_double("Delay", l->delay, l->units_delay, list);
+
+
+    list = wc_print_add_double("Metal skin depth", l->met_skindepth, l->units_depth, list);
+    list = wc_print_add_double("Substrate skin depth", l->subs_skindepth, l->units_depth, list);
+
+    list = wc_print_add_double("Total loss", l->loss, l->units_loss, list);
+    list = wc_print_add_double("Total loss per length", l->losslen, l->units_losslen, list);
+    list = wc_print_add_double("Total loss per wavelength", l->losslambda, NULL, list);
+     
+    list = wc_print_add_double("Incremental Inductance", l->Lmis, l->units_L, list);
+    list = wc_print_add_double("Incremental Capacitance", l->Cmis, l->units_C, list);
+    list = wc_print_add_double("Incremental Resistance", l->Rmis, l->units_R, list);
+    list = wc_print_add_double("Incremental Conductance", l->Gmis, l->units_G, list);
+    
+  }
+#endif
+
+  return list;
+}
 
 static void print_ps(Wcalc *wcalc, FILE *fp)
 {
