@@ -1,40 +1,26 @@
-/* $Id: wcalc.c,v 1.29 2005/11/06 02:24:12 dan Exp $ */
+/* $Id: wcalc.c,v 1.40 2009/02/11 22:34:14 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2004, 2005 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2004, 2005, 2006, 2008, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
-
 #include "config.h"
 
 #include <gtk/gtk.h>
@@ -57,10 +43,15 @@
 
 /* the individual models */
 #include "air_coil_gui.h"
+#include "bars_gui.h"
 #include "coax_gui.h"
+#include "coplanar_gui.h"
 #include "coupled_microstrip_gui.h"
+#include "coupled_stripline_gui.h"
 #include "ic_microstrip_gui.h"
 #include "microstrip_gui.h"
+#include "parallel_rc_gui.h"
+#include "parallel_rl_gui.h"
 #include "stripline_gui.h"
 
 /* libwcalc related */
@@ -233,6 +224,7 @@ int main( int   argc,
   }
   textdomain (PACKAGE);
 
+  /* FIXME -- do a better job with WCALC_RCDIR and HOME.  Look to pcb or gerbv */
   homedir = getenv("HOME");
 
   gtk_init (&argc, &argv);
@@ -266,38 +258,84 @@ static void global_model_init()
   global_model_new = NULL;
   global_model_defaults = NULL;
 
+  /* ************************ Air Coil ******************** */
   global_model_names = g_list_append(global_model_names,"Air Core Inductor");
   global_model_menus = g_list_append(global_model_menus,"/File/New/_Air Core Inductor");
   global_model_new = g_list_append(global_model_new, (gpointer) air_coil_gui_new);
   global_model_defaults = g_list_append(global_model_defaults, FILE_AIR_COIL);
 
+  /* ************************  Bars ******************** */
+  global_model_names = g_list_append(global_model_names,
+				     "Parallel Rectangular Bars");
+  global_model_menus = g_list_append(global_model_menus,"/File/New/_Bars");
+  global_model_new = g_list_append(global_model_new, (gpointer) bars_gui_new);
+  global_model_defaults = g_list_append(global_model_defaults, FILE_BARS);
+
+  /* ************************  Coax ******************** */
   global_model_names = g_list_append(global_model_names,
 				     "Coaxial Transmission Line");
   global_model_menus = g_list_append(global_model_menus,"/File/New/_Coax");
   global_model_new = g_list_append(global_model_new, (gpointer) coax_gui_new);
   global_model_defaults = g_list_append(global_model_defaults, FILE_COAX);
 
+  /* ************************  Coplanar ******************** */
+  global_model_names = g_list_append(global_model_names,
+				     "Coplanar Waveguide");
+  global_model_menus = g_list_append(global_model_menus,"/File/New/C_oplanar Waveguide");
+  global_model_new = g_list_append(global_model_new, (gpointer) coplanar_gui_new);
+  global_model_defaults = g_list_append(global_model_defaults, FILE_COPLANAR);
+
+  /* ************************ Coupled Microstrip ******************** */
   global_model_names = g_list_append(global_model_names,
 				     "Coupled Microstrip");
   global_model_menus = g_list_append(global_model_menus,
-				     "/File/New/_Coupled Microstrip");
+				     "/File/New/Co_upled Microstrip");
   global_model_new = g_list_append(global_model_new,
 				   (gpointer) coupled_microstrip_gui_new);
   global_model_defaults = g_list_append(global_model_defaults, 
 					FILE_COUPLED_MICROSTRIP);
 
+  /* ************************ Coupled Stripline ******************** */
+  global_model_names = g_list_append(global_model_names,
+				     "Coupled Stripline");
+  global_model_menus = g_list_append(global_model_menus,
+				     "/File/New/Coupled S_tripline");
+  global_model_new = g_list_append(global_model_new,
+				   (gpointer) coupled_stripline_gui_new);
+  global_model_defaults = g_list_append(global_model_defaults, 
+					FILE_COUPLED_STRIPLINE);
+
+  /* ************************ IC Microstrip ******************** */
   global_model_names = g_list_append(global_model_names,"I.C. Microstrip");
   global_model_menus = g_list_append(global_model_menus,"/File/New/_I.C. Microstrip");
   global_model_new = g_list_append(global_model_new, (gpointer) ic_microstrip_gui_new);
   global_model_defaults = g_list_append(global_model_defaults, 
 					FILE_IC_MICROSTRIP);
 
+  /* ************************ Microstrip ******************** */
   global_model_names = g_list_append(global_model_names,"Microstrip");
   global_model_menus = g_list_append(global_model_menus,"/File/New/_Microstrip");
   global_model_new = g_list_append(global_model_new, (gpointer) microstrip_gui_new);
   global_model_defaults = g_list_append(global_model_defaults, 
 					FILE_MICROSTRIP);
 
+  /* ************************  Parallel RC ******************** */
+  global_model_names = g_list_append(global_model_names,
+				     "Series/Parallel RC");
+  global_model_menus = g_list_append(global_model_menus,"/File/New/_RC");
+  global_model_new = g_list_append(global_model_new, (gpointer) parallel_rc_gui_new);
+  global_model_defaults = g_list_append(global_model_defaults, FILE_PARALLEL_RC);
+
+
+  /* ************************  Parallel RL ******************** */
+  global_model_names = g_list_append(global_model_names,
+				     "Series/Parallel RL");
+  global_model_menus = g_list_append(global_model_menus,"/File/New/R_L");
+  global_model_new = g_list_append(global_model_new, (gpointer) parallel_rl_gui_new);
+  global_model_defaults = g_list_append(global_model_defaults, FILE_PARALLEL_RL);
+
+
+  /* ************************ Stripline ******************** */
   global_model_names = g_list_append(global_model_names,"Stripline");
   global_model_menus = g_list_append(global_model_menus,"/File/New/_Stripline");
   global_model_new = g_list_append(global_model_new, (gpointer) stripline_gui_new);
@@ -462,14 +500,26 @@ void wcalc_setup (gpointer data,
       new_cmd = (void *) air_coil_gui_new;
       break;
 
+    case MODEL_BARS:
+      new_cmd = (void *) bars_gui_new;
+      break;
+      
     case MODEL_COAX:
       new_cmd = (void *) coax_gui_new;
       break;
       
+    case MODEL_COPLANAR:
+      new_cmd = (void *) coplanar_gui_new;
+      break;
+      
     case MODEL_COUPLED_MICROSTRIP:
       new_cmd = (void *) coupled_microstrip_gui_new;
       break;
 
+    case MODEL_COUPLED_STRIPLINE:
+      new_cmd = (void *) coupled_stripline_gui_new;
+      break;
+
     case MODEL_IC_MICROSTRIP:
       new_cmd = (void *) ic_microstrip_gui_new;
       break;
@@ -478,6 +528,14 @@ void wcalc_setup (gpointer data,
       new_cmd = (void *) microstrip_gui_new;
       break;
 
+    case MODEL_PARALLEL_RC:
+      new_cmd = (void *) parallel_rc_gui_new;
+      break;
+      
+    case MODEL_PARALLEL_RL:
+      new_cmd = (void *) parallel_rl_gui_new;
+      break;
+      
     case MODEL_STRIPLINE:
       new_cmd = (void *) stripline_gui_new;
       break;
@@ -531,7 +589,8 @@ void wcalc_setup (gpointer data,
   window_list = g_slist_append(window_list, wcalc->window);
 
 #ifdef DEBUG
-  g_print("wcalc_setup():  Just set wcalc->window = %p\n", wcalc->window);
+  g_print("wcalc_setup():  Created new wcalc = %p and set wcalc->window = %p\n", 
+	  wcalc, wcalc->window);
 #endif
   if ( fname != NULL ) {
     wcalc->file_name = fname;
@@ -624,6 +683,8 @@ Wcalc *Wcalc_new(void)
 
   new->units_menu_list = NULL;
 
+  new->dump_values = NULL;
+
 #ifdef DEBUG
   g_print("Wcalc_new():  New pointer is %p\n",new);
 #endif
@@ -702,8 +763,8 @@ void wcalc_set_title(Wcalc * wcalc)
   wcalc->save_needed = wcalc->window_title + strlen(wcalc->window_title) - 1;
   
 #ifdef DEBUG
-    g_print("wcalc.c:wcalc_set_title():  wcalc->window_title = \"%s\" (%p) %d len\n",
-	    wcalc->window_title, wcalc->window_title, strlen(wcalc->window_title);
+    g_print("wcalc.c:wcalc_set_title():  wcalc->window_title = \"%s\" (%p) %ld len\n",
+	    wcalc->window_title, wcalc->window_title, (long) strlen(wcalc->window_title));
     g_print("wcalc.c:wcalc_set_title():  wcalc->file_saveneeded = \"%c\" (%p)\n", 
 	    *(wcalc->save_needed), wcalc->save_needed);
 #endif
@@ -719,6 +780,8 @@ void vals_changedCB(GtkWidget *widget, gpointer data )
 
   if(gui->init_done)
     gtk_label_set_text(GTK_LABEL(gui->text_status), _("Values Out Of Sync"));
+
+  gui->values_in_sync = FALSE; 
 }
 
 
