@@ -1,36 +1,23 @@
-/* $Id: coupled_microstrip.c,v 1.26 2005/01/06 22:52:50 dan Exp $ */
+/* $Id: coupled_microstrip.c,v 1.30 2009/02/28 03:11:57 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2007, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG_SYN  */ /* debug coupled_microstrip_syn()  */
@@ -45,6 +32,7 @@
 #include "alert.h"
 #include "defaults.h"
 #include "mathutil.h"
+#include "misc.h"
 #include "physconst.h"
 #include "units.h"
 #include "coupled_microstrip.h"
@@ -94,7 +82,7 @@ static double z0_HandJ(double u);
  *  See Also:  MLICALC, MLISYN, CMLISYN, TRSUBS
 
  *  Dan McMahill, 7/17/97
- *  Copyright (c) 1997 by Dan McMahill.
+ *  Copyright (C) 1997 by Dan McMahill.
 
  *  Reference:
  *
@@ -121,7 +109,12 @@ static double z0_HandJ(double u);
  *      Constant of Microstrip with Validity up to Millimetre-Wave Frequencies"
  *      Electronics Letters, Vol 18, No. 6, March 18th, 1982, pp 272-273.
  *
- *  The loss equations are from Hammerstad and Jensen.
+ *  Kirschning and Jansen give a couple of references for where to go
+ *  for loss equations.  Hammerstad and Jensen present equations where
+ *  the conductor losses depend on a current distribution factor.  It
+ *  is perhaps easier to use Wheelers incremental inductance rule.
+ *  The dielectric losses use the standard dielectric fill factors
+ *  calculated from the even and odd mode effective dielectric constants.
  *
  *
  *  I must acknowledge the transcalc project,
@@ -133,7 +126,7 @@ static double z0_HandJ(double u);
  *
  */
 
-int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
+static int coupled_microstrip_calc_int(coupled_microstrip_line *line, double f, int do_loss)
 {
 
   /* input physical dimensions */
@@ -168,9 +161,17 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
   /* for skindepth calculation  */
   double mu,sigma,depth;
 
+  /* even and odd mode conductor and dielectric losses in nepers/meter */
+  double alpha_c_even, alpha_c_odd, alpha_d_even, alpha_d_odd;
+
+  double Ko, Rs, lc, Res, delta, Q_c_even, Q_c_odd;
+  
+  /* correction factor for surface roughness */
+  double rough_factor;
 
 #ifdef DEBUG_CALC
   printf("coupled_microstrip_calc(): --------- Coupled_Microstrip Analysis ----------\n");
+  printf("coupled_microstrip_calc(): do_loss                     = %d\n", do_loss);
   printf("coupled_microstrip_calc(): Metal width                 = %g %s\n",
 	 line->w/line->units_lwst->sf, line->units_lwst->name);
   printf("coupled_microstrip_calc(): Metal spacing               = %g %s\n",
@@ -537,25 +538,52 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
    * Note:  This line contains one of the published corrections.
    * The second EFF from the original paper is replaced by EF.
    */
-  z0ef = z0e0 
-    * (pow((0.9408*pow(EFF,CE) - 0.9603),Q0))
-    /(pow(((0.9408 - DE)*pow(EF,CE) - 0.9603),Q0));
+#ifdef DEBUG_CALC
+  printf ("%s():  EFF = %g\n", __FUNCTION__, EFF);
+  printf ("%s():  CE  = %g\n", __FUNCTION__, CE);
+  printf ("%s():  DE  = %g\n", __FUNCTION__, DE);
+  printf ("%s():  EF  = %g\n", __FUNCTION__, EF);
+#endif
 
+  if (er > 1.0) {
+    z0ef = z0e0 
+      * (pow((0.9408*pow(EFF,CE) - 0.9603),Q0))
+      /(pow(((0.9408 - DE)*pow(EF,CE) - 0.9603),Q0));
+  } else {
+    /* no dispersion for er = 1.0 */
+    z0ef = z0e0;
+  }
 
   /*
    * odd mode characteristic impedance including dispersion
    * This is (11) from Kirschning and Jansen (MTT)
    */
-  Q29 = 15.16/(1.0 + 0.196*pow((er-1.0),2.0));
-  Q28 = 0.149*(pow((er-1.0),3.0))/(94.5 + 0.038*pow((er-1.0),3.0));
-  Q27 = 0.4*pow(g,0.84)
-    *(1.0 + 2.5*(pow((er-1.0),1.5))/(5.0 + pow((er-1.0),1.5)));
-  Q26 = 30.0 
-    - 22.2*(( pow(((er-1.0)/13.0),12.0)) 
-	    / (1.0 + 3.0*pow(((er-1.0)/13.0),12.0))) 
-    - Q29;
-  Q25 = (0.3*fn*fn/(10.0 + fn*fn))
-    *(1.0 + 2.333*(pow((er-1.0),2.0))/(5.0 + pow((er-1.0),2.0)));
+
+  if( er > 1.0) {
+    Q29 = 15.16/(1.0 + 0.196*pow((er-1.0),2.0));
+    Q28 = 0.149*(pow((er-1.0),3.0))/(94.5 + 0.038*pow((er-1.0),3.0));
+    Q27 = 0.4*pow(g,0.84)
+      *(1.0 + 2.5*(pow((er-1.0),1.5))/(5.0 + pow((er-1.0),1.5)));
+    Q26 = 30.0 
+      - 22.2*(( pow(((er-1.0)/13.0),12.0)) 
+	      / (1.0 + 3.0*pow(((er-1.0)/13.0),12.0))) 
+      - Q29;
+    Q25 = (0.3*fn*fn/(10.0 + fn*fn))
+      *(1.0 + 2.333*(pow((er-1.0),2.0))/(5.0 + pow((er-1.0),2.0)));
+  } else {
+    /* it seems that pow(0.0, x) gives a floating exception */
+    Q29 = 15.16/(1.0 + 0.196);
+    Q28 = 0.149/(94.5 + 0.038*1.0);
+    Q27 = 0.4*pow(g,0.84)
+      *(1.0 + 2.5/(5.0 + 1.0));
+    Q26 = 30.0 
+      - 22.2*(( 1.0 ) 
+	      / (1.0 + 3.0)) 
+      - Q29;
+    Q25 = (0.3*fn*fn/(10.0 + fn*fn))
+      *(1.0 + 2.333*(1.0)/(5.0 + 1.0));
+  }
+
   Q24 = 2.506*Q28*pow(u,0.894)
     *(pow(((1.0 + 1.3*u)*fn/99.25),4.29))/(3.575 + pow(u,0.894));
   Q23 = 1.0 + 0.005*fn*Q27/((1.0 + 0.812*pow((fn/15.0),1.9))*
@@ -566,7 +594,11 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
    * in this final expression, ZLF is the frequency dependent single
    * microstrip characteristic impedance from Jansen and Kirschning.
    */
-  z0of = ZLF + (z0o0*pow((EFOF/EFO0),Q22) - ZLF*Q23)/(1.0 + Q24 + (pow((0.46*g),2.2))*Q25);
+  if (er > 1.0) {
+    z0of = ZLF + (z0o0*pow((EFOF/EFO0),Q22) - ZLF*Q23)/(1.0 + Q24 + (pow((0.46*g),2.2))*Q25);
+  } else {
+    z0of = z0o0;
+  }
 
 #ifdef DEBUG_CALC
   printf("1.0 + 0.812*pow((fn/15.0),1.9) = %g\n",
@@ -629,15 +661,10 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
     line->losslen_ev = 0.0;
     line->losslen_odd = 0.0;
   }
-  
-  /* loss in dB/meter */
-  line->losslen_ev  = 20.0*log10(exp(1.0)) * line->losslen_ev;
-  line->losslen_odd = 20.0*log10(exp(1.0)) * line->losslen_odd;
-  
+  /* remember these two for later */
+  alpha_d_even = line->losslen_ev;
+  alpha_d_odd = line->losslen_odd;
 
-  /* loss in dB */
-  line->loss_ev = l * line->losslen_ev;
-  line->loss_odd = l * line->losslen_odd;
   
 #ifdef DEBUG_CALC
   printf("coupled_microstrip_calc():  Even mode dielectric loss = %g dB/m \n",
@@ -675,66 +702,159 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
    * with a better result.
    */
 
-/* XXX need to turn on copper loss!!!!! */
-#ifdef notdef   
-  if(depth <= t)
-    {
-      
-      /*
-       * Find the current distribution factor.  This is (39) from
-       * Hammerstad and Jensen.
-       */
-      Ko = exp(-1.2*pow( (z0e0 + z0o0)/(2.0*FREESPACEZ0), 0.7));
+  alpha_c_even = 0.0;
+  alpha_c_odd = 0.0;
+  delta = depth;
+  lc = 0.0;
 
+  if (do_loss) {
+    if(3.0*depth <= t &&
+       3.0*depth <= w)
+      {
+	
+	/*
+	 * Find the current distribution factor.  This is (39) from
+	 * Hammerstad and Jensen.
+	 */
+	Ko = exp(-1.2*pow( sqrt(er)*(z0e0 + z0o0)/(2.0*FREESPACEZ0), 0.7));
+
+
+	/* skin resistance */
+	Rs = 1.0 / (sigma * depth);
 #ifdef DEBUG_CALC
-      printf("coupled_microstrip_calc():  Ko = %g\n",Ko);
+	printf("%s():  Ko = %g\n", __FUNCTION__, Ko);
+	printf("%s():  Skin resistance = %g Ohm, sigma = %g mho/m, skin depth = %g m\n",
+	       __FUNCTION__, Rs, sigma, depth);
 #endif
 
-      /* skin resistance */
-      Rs = 1.0 / (sigma * depth);
+	/*
+	 * Inductive quality factor (34) from Hammerstand and Jensen
+	 *
+	 * FIXME -- should these be the impedances with or without
+	 * dispersion?  Does is really matter that much for a loss
+	 * calculation which I think in general may be a little less accurate?
+	 *
+	 * The impedance here is the impedance in a homogeneous
+	 * dielectric.  See (1) and (8) in Hammerstad and Jensen. 
+	 */
+	Q_c_even = (M_PI * z0e0 * sqrt(EFEF) * h * f / (Rs * LIGHTSPEED)) * (u/Ko);
+	Q_c_odd  = (M_PI * z0o0 * sqrt(EFOF) * h * f / (Rs * LIGHTSPEED)) * (u/Ko);
 
-      /* conduction losses, nepers per meter */
-      lc = (M_PI*z0e0*h*f/(Rs*LIGHTSPEED))*(u/Ko);
-      /* dB/meter */
-      lc = 20.0*log10(exp(1.0)) * lc;
+#ifdef DEBUG_CALC
+	printf("%s():  Q_c_even = %g\n", __FUNCTION__, Q_c_even);
+	printf("%s():  Q_c_odd = %g\n", __FUNCTION__, Q_c_odd);
+#endif
 
-      printf("coupled_microstrip_calc():  Even mode conduction loss = %g dB/m",
-	     lc);
+	/*
+	 * (38) from Hammerstad and Jensen says (after converting to
+	 * nepers/meter)
+	 * alpha_c = pi * lightpeed / (Q * f * sqrt(keff)
+	 *         = pi * lambda_g / Q where lambda_g is the guided
+	 * wavelength
+	 *
+	 * However, I think they have the lambda_g on the wrong side
+	 *
+	 */
+	alpha_c_even = M_PI * f *sqrt(EFEF) / (Q_c_even * LIGHTSPEED);
+	alpha_c_odd = M_PI * f *sqrt(EFOF) / (Q_c_odd * LIGHTSPEED);
 
-      /* conduction losses, nepers per meter */
-      lc = (M_PI*z0o0*h*f/(Rs*LIGHTSPEED))*(u/Ko);
-      /* dB/meter */
-      lc = 20.0*log10(exp(1.0)) * lc;
+#ifdef DEBUG_CALC
+	printf("%s():  Even mode conduction loss = %g dB/m\n",
+	       __FUNCTION__, 20.0*log10(exp(1.0)) * alpha_c_even);
+	printf("%s():  Odd mode conduction loss = %g dB/m\n",
+	       __FUNCTION__, 20.0*log10(exp(1.0)) * alpha_c_odd);
+#endif
+	
+	/* 
+	 * Instead try out Wheelers incremental inductance rule 
+	 * for some reason, I'm getting more loss (almost a factor of
+	 * 2) from the above formulation.  Using the incremental
+	 * inductance approach below, I get an answer which is close
+	 * to single microstrip when I make the spacing between traces
+	 * wide.  Until I can get an electromagnetic solver going, go
+	 * with the incremental inductance approach.
+	 */
 
-      printf("coupled_microstrip_calc():  Even mode conduction loss = %g dB/m",
-	     lc);
-    }
+	{
+	  coupled_microstrip_line tmp_line;
+	  int rslt;
+	  double z1e, z1o, z2e, z2o;
+
+	  /* clone the line */
+	  tmp_line = *line;
+	  tmp_line.subs = microstrip_subs_new();
+	  *(tmp_line.subs) = *(line->subs);
+	   
+	  tmp_line.subs->er = 1.0;
+	  rslt = coupled_microstrip_calc_int(&tmp_line, f, 0);
+	  z1e = tmp_line.z0e;
+	  z1o = tmp_line.z0o;
+	  
+	  tmp_line.w = line->w - depth;
+	  tmp_line.s = line->s + depth;
+	  tmp_line.subs->tmet = line->subs->tmet - depth;
+	  tmp_line.subs->h = line->subs->h + depth;
+	  rslt = coupled_microstrip_calc_int(&tmp_line, f, 0);
+	  z2e = tmp_line.z0e;
+	  z2o = tmp_line.z0o;
+	  
+	  free(tmp_line.subs);
+	  
+	  
+	  /* conduction losses, nepers per meter */
+	  alpha_c_even = (M_PI*f/LIGHTSPEED)*(z2e - z1e)/z0ef;
+	  alpha_c_odd = (M_PI*f/LIGHTSPEED)*(z2o - z1o)/z0of;
+	  
+#ifdef DEBUG_CALC
+
+	  printf("%s():  Odd mode conduction loss = %g dB/m (Via Wheelers incremental inductance)\n",
+		 __FUNCTION__, 20.0*log10(exp(1.0))*alpha_c_odd);
+	  printf("%s():  Even mode conduction loss = %g dB/m (Via Wheelers incremental inductance)\n",
+		 __FUNCTION__, 20.0*log10(exp(1.0))*alpha_c_even);
+
+	  if (z2e > z1e) {
+	    printf("%s():  Q_c_even (via incremental inductance) = %g\n", __FUNCTION__, sqrt(EFEF)*z0ef / (z2e - z1e));
+	  } else {
+	    printf("%s():  Q_c_even (via incremental inductance) = Infinite\n", __FUNCTION__);
+	  }
+	  if (z2o > z1o) {
+	    printf("%s():  Q_c_odd  (via incremental inductance) = %g\n", __FUNCTION__, sqrt(EFOF)*z0of / (z2o - z1o));
+	  } else {
+	    printf("%s():  Q_c_odd  (via incremental inductance) = Infinite\n", __FUNCTION__);
+	  }
+#endif
+
+	}
+
+      }
   
-  /* "dc" case  */
-  else if(t > 0.0)
-    {
-      /* resistance per meter = 1/(Area*conductivity) */
-      Res = 1/(w*t*sigma);  
+    /* "dc" case  */
+    else if(t > 0.0)
+      {
+	/* resistance per meter = 1/(Area*conductivity) */
+	Res = 1/(w*t*sigma);  
       
-      /* conduction losses, nepers per meter */
-      lc = Res/(2.0*z0);
+	/* conduction losses, nepers per meter */
+	alpha_c_even = Res/(2.0*z0e0);;
+	alpha_c_odd = Res/(2.0*z0o0);
+	lc = Res / (2.0 * sqrt(z0e0 * z0o0));
+
+	/* dB/meter */
+	lc = 20.0*log10(exp(1.0)) * lc;
+
+	/*
+	 * change delta to be equal to the metal thickness for
+	 * use in surface roughness correction
+	 */
+	delta = t;
       
-      /*
-       * change delta to be equal to the metal thickness for
-       * use in surface roughness correction
-       */
-      delta = t;
-      
-      /* no conduction loss case */
-    }
-  else
-    {
-      lc=0.0;
-    }
-  
- 
-  /* loss in dB/meter */
-  lc = 20.0*log10(exp(1.0)) * lc;
+	/* no conduction loss case */
+      }
+    else
+      {
+	lc = 0.0;
+      }
+  }
   
   /* loss in dB */
   lc = lc * l;
@@ -746,8 +866,13 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
    * found in Hammerstad and Bekkadal as well as Hammerstad and Jensen 
    */
    /* XXX this was roughmil/delta double check it */
-  lc = lc * (1.0 + (2.0/M_PI)*atan(1.4*pow((rough/delta),2.0)));
-  
+  rough_factor = 1.0 + (2.0/M_PI)*atan(1.4*pow((rough/delta),2.0));
+  lc = lc * rough_factor;
+  alpha_c_even = alpha_c_even * rough_factor;
+  alpha_c_odd = alpha_c_odd * rough_factor;
+
+#ifdef DEBUG_CALC
+  printf ("%s():  rough_factor = %g \n", __FUNCTION__, rough_factor);
 #endif
 
   /*
@@ -820,16 +945,35 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
   line->Lodd = line->z0o * sqrt(line->kodd) / LIGHTSPEED;
   line->Codd = sqrt(line->kodd) / (line->z0o * LIGHTSPEED);
 
-  /* XXX fix the loss */
+  
+  line->Rev = alpha_c_even * 2.0 * z0ef;
+  line->Gev = 2.0 * alpha_d_even / z0ef;
 
-  line->Rev = 0.0;
-  line->Gev = 0.0;
-  line->Rodd = 0.0;
-  line->Godd = 0.0;
+  line->Rodd = alpha_c_odd * 2.0 * z0of;
+  line->Godd = 2.0 * alpha_d_odd / z0of;
+
+#ifdef DEBUG_CALC
+  printf ("Rev  (%g) = alpha_c_even (%g) * 2.0 * z0ef (%g)\n", line->Rev, alpha_c_even, z0ef);
+  printf ("Rodd (%g) = alpha_c_odd  (%g) * 2.0 * z0of (%g)\n", line->Rodd, alpha_c_odd, z0of);
+#endif
+
+  /* loss in dB/meter */
+  line->losslen_ev  = 20.0*log10(exp(1.0)) * (alpha_c_even + alpha_d_even);
+  line->losslen_odd = 20.0*log10(exp(1.0)) * (alpha_c_odd + alpha_d_odd);
+  
+
+  /* loss in dB */
+  line->loss_ev = l * line->losslen_ev;
+  line->loss_odd = l * line->losslen_odd;
 
   return 0;
 }
 
+int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
+{
+ return coupled_microstrip_calc_int(line, f, 1);
+}
+
 /*function [w,l,s,loss,kev,kodd]=cmlisyn(z0e,z0o,len,f,subs) */
 /* CMLISYN    Synthesize coupled microstrip transmission line from electrical parameters
  *
@@ -863,7 +1007,7 @@ int coupled_microstrip_calc(coupled_microstrip_line *line, double f)
  *  See Also:  CMLICALC, MLISYN, MLICALC, SLISYN, SLICALC, TRSUBS
  *
  *  Dan McMahill, 7/17/97
- *  Copyright (c) 1997 by Dan McMahill.
+ *  Copyright (C) 1997 by Dan McMahill.
  *
  */
 
@@ -1028,7 +1172,8 @@ int coupled_microstrip_syn(coupled_microstrip_line *line, double f)
       iters++;
       line->w = w;
       line->s = s;
-      coupled_microstrip_calc(line, line->freq);
+      /* don't bother with loss calculations while we are iterating */
+      coupled_microstrip_calc_int(line, line->freq, 0);
       
       ze0 = line->z0e;
       zo0 = line->z0o;
@@ -1048,13 +1193,13 @@ int coupled_microstrip_syn(coupled_microstrip_line *line, double f)
 	/* approximate the first jacobian */
 	line->w = w + delta;
 	line->s = s;
-	coupled_microstrip_calc(line, line->freq);
+	coupled_microstrip_calc_int (line, line->freq, 0);
 	ze1 = line->z0e;
 	zo1 = line->z0o;
 
 	line->w = w;
 	line->s = s + delta;
-	coupled_microstrip_calc(line, line->freq);
+	coupled_microstrip_calc_int (line, line->freq, 0);
 	ze2 = line->z0e;
 	zo2 = line->z0o;
 
@@ -1097,11 +1242,15 @@ int coupled_microstrip_syn(coupled_microstrip_line *line, double f)
   
   line->w = w;
   line->s = s;
-  coupled_microstrip_calc(line, line->freq);
+  coupled_microstrip_calc_int (line, line->freq, 0);
 
   /* scale the line length to get the desired electrical length */
   line->l = line->l * len/line->len;
-  coupled_microstrip_calc(line, line->freq);
+
+  /* 
+   * one last calculation and this time we find the loss too.
+   */
+  coupled_microstrip_calc_int (line, line->freq, 1);
 
 #ifdef DEBUG_SYN
   printf("Took %d iterations, err = %g\n", iters, err);
@@ -1117,6 +1266,10 @@ int coupled_microstrip_syn(coupled_microstrip_line *line, double f)
 static double ee_HandJ(double u, double er)
 {
   double A,B,E0;
+  
+#ifdef DEBUG_CALC
+  printf ("%s(%g, %g)\n", __FUNCTION__, u, er);
+#endif
 
   /* (4) from Hammerstad and Jensen */
   A = 1.0 + (1.0/49.0)
