@@ -1,36 +1,23 @@
-/* $Id: mathutil.c,v 1.10 2002/06/12 11:30:28 dan Exp $ */
+/* $Id: mathutil.c,v 1.12 2008/11/29 20:42:16 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2006 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG_C_DIV */
@@ -1692,5 +1679,36 @@ complex * c_hankel1_2_p(complex *x, complex *H)
 }
 
 
+ /*
+  *  compute K(k)/K'(k) where
+  * K is the complete elliptic integral of the first kind,
+  * K' is the complementary complete elliptic integral of the first kind
+  */
+
+double k_over_kp(double k)
+{
+  double kp, r, kf;
+  int i = 0;
+
+  kp = sqrt(1.0-pow(k,2.0));
+  r = 1.0;
+  do {
+    kf = (1.0 + k) / (1.0 + kp);
+    r = r*kf;
+    k = 2.0*sqrt(k) / (1.0 + k);
+    kp = 2.0*sqrt(kp) / (1.0 + kp);
+    i++;
+  } while( (fabs(kf - 1.0) > 1e-15) && ( i < 20) );
+
+/* alternate approach
+  if( k < sqrt(0.5) ) {
+    kp = sqrt(1.0 - k*k);
+    r = M_PI / log(2.0 * (1.0 + sqrt(kp)) / (1.0 - sqrt(kp)) );
+  } else {
+    r = log(2.0 * (1.0 + sqrt(k)) / (1.0 - sqrt(k)) ) / M_PI;
+  }
+*/
+  return r;
+}
 
 
