@@ -1,36 +1,23 @@
-/* $Id: microstrip.c,v 1.19 2004/08/31 21:38:21 dan Exp $ */
+/* $Id: microstrip.c,v 1.23 2009/02/28 03:13:13 dan Exp $ */
 
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2004 Dan McMahill
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2006, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG_CALC */   /* debug the microstrip_calc() function */
@@ -123,6 +110,9 @@ static double z0_HandJ(double u);
  *    ELAB Report STF44 A74169, February 1975
  *    University of Trondheim, Norway
  *
+ *    Edgar J. Denlinger, "Losses of Microstrip Lines",
+ *    IEEE Trnasactions on Microwave Theory and Techniques,
+ *    Vol MTT-28, No. 6, June 1980, pp. 513-522.
  *
  *
  * flag=1 enables loss calculations
@@ -415,9 +405,9 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
    L = z0/v;
    C = 1.0/(z0*v);
   
-   /* resistance will be updated below */
+   /* resistance and conductance will be updated below */
    R = 0.0;
-   G = 2*M_PI*f*C*line->subs->tand;
+   G = 0.0;
 
    if(flag == WITHLOSS)
      {
@@ -433,7 +423,7 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 
 
        /* effective relative permittivity */
-       eeff=EF;
+       eeff = EF;
 
 
        line->keff = eeff;
@@ -447,17 +437,42 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	*/
    
        /* loss in nepers/meter */
+
+       /* 
+	* The dielectric loss here matches equation (1) in the
+	* Denlinger paper although the form is slightly different.  In
+	* the Denlinger paper it is in dB/m.  Note that the 27.3 in
+	* the Denlinger paper is equal to pi * 20*log10( e ).
+	*
+	* See also equation (4.21) in Fooks and Zakarevicius.  The
+	* difference in form there is (4.21) uses c/sqrt(EF) in place
+	* of 'v' in our equation here.
+	*
+	*
+	* With a uniform dielectric, we would have this:
+	*
+	* G = 2 * M_PI * f * C * line->subs->tand;
+	*
+	* alpha_d = (G * Z0 / 2) * tand     (nepers/meter)
+	*
+	* but for the mixed air/dielectric that we have, the loss is
+	* less by a factor qd which is the filling factor.
+	* bu
+	*/
+       
        if (er > 1.0) {
 	 ld=(M_PI*f/v)*(er/EF)*((EF-1.0)/(er-1.0))*tand;
        }
        else {
-	 /* XXX verify this one */
+	 /* if er == 1, then this is probably a vacuum */
 	 ld = 0.0;
        }
-
+       
+       G = 2.0 * ld / z0;
+       line->alpha_d = ld;
+       
        /* loss in dB/meter */
        ld = 20.0*log10(exp(1.0)) * ld;
-       line->alpha_d = ld;
 
        /* loss in dB */
        ld = ld * l;
@@ -508,7 +523,10 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	   if (rslt)
 	     return rslt;
 	   z2=line->z0;
-
+#ifdef DEBUG_CALC
+	   printf("%s(): z2 = %g Ohms (er = 1.0, nom dimensions)\n",
+		  __FUNCTION__, z2);
+#endif
 
 	   line->subs->h = h + delta;
 	   line->subs->tmet = t - delta;
@@ -517,6 +535,18 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	   if (rslt)
 	     return rslt;
 	   z1=line->z0;
+#ifdef DEBUG_CALC
+	   printf("%s(): z1 = %g Ohms (er = 1.0, w=%g %s, h=%g %s, t=%g %s)\n",
+		  __FUNCTION__, z1, 
+		  line->w/line->units_lwht->sf, line->units_lwht->name,
+		  line->subs->h/line->units_lwht->sf, line->units_lwht->name,
+		  line->subs->tmet/line->units_lwht->sf, line->units_lwht->name);
+	   printf("%s(): delta = %g m (%g %s)\n", __FUNCTION__,
+		  delta, delta/line->units_lwht->sf, line->units_lwht->name);
+
+	   printf("%s(): z1 - z2 = %g Ohms\n", __FUNCTION__, z1 - z2);
+#endif
+
 	   line->subs->er = er;
 	   line->subs->h = h;
 	   line->subs->tmet = t;
@@ -525,7 +555,7 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	   /* conduction losses, nepers per meter */
 	   lc = (M_PI*f/LIGHTSPEED)*(z1 - z2)/z0;
 
-	   R = lc*2*line->z0;
+	   R = lc*2*z0;
 	 }
 
 	   /* "dc" case  */
@@ -554,9 +584,6 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	 }
 
  
-       /* loss in dB/meter */
-       lc = 20.0*log10(exp(1.0)) * lc;
-
    
        /* factor due to surface roughness
 	* note that the equation in Fooks and Zakarevicius is slightly 
@@ -565,8 +592,22 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
 	* found in Hammerstad and Bekkadal
 	*/
        lc = lc * (1.0 + (2.0/M_PI)*atan(1.4*pow((rough/delta),2.0)));
+
        line->alpha_c = lc;
-   
+
+       /*
+	* recalculate R now that we have the surface roughness in
+	* place 
+	*/
+       R = lc*2.0*z0;
+
+#ifdef DEBUG_CALC
+       printf ("R (%g) = alpha_c (%g) * 2.0 * z0 (%g)\n", R, lc, z0);
+#endif
+
+       /* loss in dB/meter */
+       lc = 20.0*log10(exp(1.0)) * lc;
+
        /* loss in dB */
        lc = lc * l;
 
@@ -594,10 +635,10 @@ static int microstrip_calc_int(microstrip_line *line, double f, int flag)
    line->delay = delay;
 
    line->Ls = L;
-	line->Rs = R; 
-	line->Cs = C;
-	line->Gs = G;
-
+   line->Rs = R; 
+   line->Cs = C;
+   line->Gs = G;
+   
 
    return (rslt);
 }
