@@ -1,40 +1,32 @@
-/*      $Id: stripline.c,v 1.18 2004/12/04 00:26:50 dan Exp $ */
+/*      $Id: stripline.c,v 1.24 2009/02/27 05:23:31 dan Exp $ */
 
 /*
- * Copyright (c) 1999, 2000, 2001, 2002, 2004 Dan McMahill
+ * Copyright (C) 1999, 2000, 2001, 2002, 2004, 2006 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /*
  *  References:
+ *
+ *    S. B. Cohn, "Characteristic Impedance of the Shielded-Strip Transmission Line",
+ *    IRE Transactions on Microwave Theory and Techniques, Vol MTT-2,
+ *    No 2, July 1954, pp. 52-57.
+ *
  *    Stanislaw Rosloniec
  *    "Algorithms For Computer-Aided Design of Linear Microwave Circuits"
  *    Archtech House, 1990
@@ -249,6 +241,11 @@ static int stripline_calc_int(stripline_line *line, double f, int flag)
   
    /* resistance will be updated below */
    R = 0.0;
+
+   /* 
+    * this formulation for G works because we have a uniform
+    * dielectric 
+    */
    G = 2*M_PI*f*C*line->subs->tand;
 
    delay = line->l / v;
@@ -266,7 +263,7 @@ static int stripline_calc_int(stripline_line *line, double f, int flag)
 	*/
    
        /* loss in nepers/meter */
-       ld=line->Gs*line->z0/2;
+       ld = G*z0/2;
 
        /* loss in dB/meter */
        ld = 20.0*log10(exp(1.0)) * ld;
@@ -336,9 +333,9 @@ static int stripline_calc_int(stripline_line *line, double f, int flag)
 	   lc = (M_PI*f/LIGHTSPEED)*(z2 - z1)/z0;
 #ifdef DEBUG_CALC
 	   printf("stripline_calc_int(): HF conduction loss, z1=%g,z2=%g,z0=%g,lc=%g\n",
-		  z1,z2,z0,lc);
+		  z1, z2, z0, lc);
 #endif
-	   R = lc*2*line->z0;
+	   R = lc * 2.0 * z0;
 
 	 }
 
