@@ -1,36 +1,23 @@
-/* $Id: wcalc_loadsave.c,v 1.24 2005/02/12 15:02:22 dan Exp $ */
+/* $Id: wcalc_loadsave.c,v 1.30 2009/02/11 22:34:20 dan Exp $ */
 
 /*
- * Copyright (c) 2001, 2002, 2004, 2005 Dan McMahill
+ * Copyright (C) 2001, 2002, 2004, 2005, 2006, 2008 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* #define DEBUG */
@@ -130,18 +117,33 @@ int wcalc_load(FILE *fp)
   if (strcmp(val, FILE_AIR_COIL) == 0) {
     return MODEL_AIR_COIL;
   }
+  else if (strcmp(val, FILE_BARS) == 0) {
+    return MODEL_BARS;
+  }
   else if (strcmp(val, FILE_COAX) == 0) {
     return MODEL_COAX;
   }
+  else if (strcmp(val, FILE_COPLANAR) == 0) {
+    return MODEL_COPLANAR;
+  }
   else if (strcmp(val, FILE_COUPLED_MICROSTRIP) == 0) {
     return MODEL_COUPLED_MICROSTRIP;
   }
+  else if (strcmp(val, FILE_COUPLED_STRIPLINE) == 0) {
+    return MODEL_COUPLED_STRIPLINE;
+  }
   else if (strcmp(val, FILE_IC_MICROSTRIP) == 0) {
     return MODEL_IC_MICROSTRIP;
   }
   else if (strcmp(val, FILE_MICROSTRIP) == 0) {
     return MODEL_MICROSTRIP;
   }
+  else if (strcmp(val, FILE_PARALLEL_RC) == 0) {
+    return MODEL_PARALLEL_RC;
+  }
+  else if (strcmp(val, FILE_PARALLEL_RL) == 0) {
+    return MODEL_PARALLEL_RL;
+  }
   else if (strcmp(val, FILE_STRIPLINE) == 0) {
     return MODEL_STRIPLINE;
   }
