@@ -1,36 +1,23 @@
-/* $Id: main.c,v 1.19 2005/10/15 00:40:02 dan Exp $ */
+/* $Id: main.c,v 1.32 2009/02/28 03:14:03 dan Exp $ */
 
 /*
- * Copyright (c) 2004, 2005 Dan McMahill
+ * Copyright (C) 2004, 2005, 2006, 2007, 2009 Dan McMahill
  * All rights reserved.
  *
- * This code is derived from software written by Dan McMahill
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by Dan McMahill
- * 4. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * 
  */
 
 /* echo "ic_microstrip_calc 20e-6 1e-3 5e-6 4.0 200e-6 11.8 1.0 1e-6
@@ -69,10 +56,15 @@
 /* Headers for the various structures we can analyze */
 
 #include "air_coil.h"
+#include "bars.h"
 #include "coax.h"
+#include "coplanar.h"
 #include "coupled_microstrip.h"
+#include "coupled_stripline.h"
 #include "ic_microstrip.h"
 #include "microstrip.h"
+#include "parallel_rc.h"
+#include "parallel_rl.h"
 #include "stripline.h"
 
 #ifdef DMALLOC
@@ -83,15 +75,24 @@
 
 /* local prototypes */
 static void exec_air_coil_calc(double *args);
+static void exec_bars_calc(double *args);
 static void exec_coax_calc(double *args);
+static void exec_coplanar_calc(double *args);
 static void exec_coupled_microstrip_calc(double *args);
+static void exec_coupled_stripline_calc(double *args);
 static void exec_ic_microstrip_calc(double *args);
 static void exec_microstrip_calc(double *args);
+static void exec_parallel_rc_p2s(double *args);
+static void exec_parallel_rc_s2p(double *args);
+static void exec_parallel_rl_p2s(double *args);
+static void exec_parallel_rl_s2p(double *args);
 static void exec_stripline_calc(double *args);
 
 static void exec_air_coil_syn(double *args);
 static void exec_coax_syn(double *args);
+static void exec_coplanar_syn(double *args);
 static void exec_coupled_microstrip_syn(double *args);
+static void exec_coupled_stripline_syn(double *args);
 static void exec_ic_microstrip_syn(double *args);
 static void exec_microstrip_syn(double *args);
 static void exec_stripline_syn(double *args);
@@ -222,18 +223,33 @@ static void execute_file(FILE *fp, char *fname)
     } else if(strcmp(tok, "air_coil_syn") == 0) {
       narg = 9;
       fn = &exec_air_coil_syn;
+    } else if(strcmp(tok, "bars_calc") == 0) {
+      narg = 10;
+      fn = &exec_bars_calc;
     } else if(strcmp(tok, "coax_calc") == 0) {
       narg = 10;
       fn = &exec_coax_calc;
     } else if(strcmp(tok, "coax_syn") == 0) {
       narg = 12;
       fn = &exec_coax_syn;
+    } else if(strcmp(tok, "coplanar_calc") == 0) {
+      narg = 11;
+      fn = &exec_coplanar_calc;
+    } else if(strcmp(tok, "coplanar_syn") == 0) {
+      narg = 14;
+      fn = &exec_coplanar_syn;
     } else if(strcmp(tok, "coupled_microstrip_calc") == 0) {
       narg = 10;
       fn = &exec_coupled_microstrip_calc;
     } else if(strcmp(tok, "coupled_microstrip_syn") == 0) {
       narg = 14;
       fn = &exec_coupled_microstrip_syn;
+    } else if(strcmp(tok, "coupled_stripline_calc") == 0) {
+      narg = 10;
+      fn = &exec_coupled_stripline_calc;
+    } else if(strcmp(tok, "coupled_stripline_syn") == 0) {
+      narg = 14;
+      fn = &exec_coupled_stripline_syn;
     } else if(strcmp(tok, "ic_microstrip_calc") == 0) {
       narg = 11;
       fn = &exec_ic_microstrip_calc;
@@ -246,6 +262,18 @@ static void execute_file(FILE *fp, char *fname)
     } else if(strcmp(tok, "microstrip_syn") == 0) {
       narg = 12;
       fn = &exec_microstrip_syn;
+    } else if(strcmp(tok, "parallel_rc_p2s") == 0) {
+      narg = 5;
+      fn = &exec_parallel_rc_p2s;
+    } else if(strcmp(tok, "parallel_rc_s2p") == 0) {
+      narg = 5;
+      fn = &exec_parallel_rc_s2p;
+    } else if(strcmp(tok, "parallel_rl_p2s") == 0) {
+      narg = 5;
+      fn = &exec_parallel_rl_p2s;
+    } else if(strcmp(tok, "parallel_rl_s2p") == 0) {
+      narg = 5;
+      fn = &exec_parallel_rl_s2p;
     } else if(strcmp(tok, "stripline_calc") == 0) {
       narg = 9;
       fn = &exec_stripline_calc;
@@ -370,6 +398,48 @@ static void exec_air_coil_syn(double *args)
   return;
 }
 
+/*
+ * [L1, L2, M, k] = 
+ *  bars_calc(a, b, l1, d, c, l2, E, P, l3, f);
+ */
+static void exec_bars_calc(double *args)
+{
+  /* our bars for calculations */
+  bars *bar;
+  int i = 0;
+
+  /* create the bars and fill in the parameters */
+  bar = bars_new();
+
+  bar->a        = args[i++];
+  bar->b        = args[i++];
+  bar->l1       = args[i++];
+
+  bar->d        = args[i++];
+  bar->c        = args[i++];
+  bar->l2       = args[i++];
+
+  bar->E        = args[i++];
+  bar->P        = args[i++];
+  bar->l3       = args[i++];
+
+  bar->freq    = args[i++];
+
+  /* run the calculation */
+  if( bars_calc(bar, bar->freq) ) {
+    printf("%s", ERRMSG);
+  } else { 
+    /* print the outputs */
+    printf("%g %g %g %g\n", 
+	   bar->L1, bar->L2,
+	   bar->M, bar->k);
+  }
+
+  /* clean up */
+  bars_free(bar);
+  
+  return;
+}
 /*
  * [z0,elen,loss,L,R,C,G] = 
  *  coax_calc(a,b,c,t,rho_a,rho_b,er,tand,len,f);
@@ -450,6 +520,86 @@ static void exec_coax_syn(double *args)
   return;
 }
 
+static void exec_coplanar_calc(double *args)
+{
+  /* our coax for calculations */
+  coplanar_line *line;
+  int i = 0;
+
+  /* create the line and fill in the parameters */
+  line = coplanar_line_new();
+  line->w           = args[i++];
+  line->s           = args[i++];
+  line->subs->h     = args[i++];
+  line->l           = args[i++];
+  line->subs->tmet  = args[i++];
+  line->subs->rho   = args[i++];
+  line->subs->rough = args[i++];
+  line->subs->er    = args[i++];
+  line->subs->tand  = args[i++];
+  line->with_ground = args[i++];
+  line->freq        = args[i++];
+
+  /* run the calculation */
+  if( coplanar_calc(line, line->freq) ) {
+    printf("%s", ERRMSG);
+  } else { 
+    /* print the outputs */
+    printf("%g %g %g %g %g %g %g %g %g %g %g %g \n", line->z0, line->keff,
+	   line->len, line->loss, line->Ls, line->Rs, line->Cs, line->Gs,
+	   line->lc, line->ld, line->deltal, line->skindepth);
+  }
+
+  /* clean up */
+  coplanar_line_free(line);
+  
+  return;
+}
+
+/*
+ * FIXME
+ */
+static void exec_coplanar_syn(double *args)
+{
+  /* our coax for calculations */
+  coplanar_line *line;
+  int i = 0;
+  int flag;
+
+  /* create the line and fill in the parameters */
+  line = coplanar_line_new();
+  line->Xo          = 0.0;
+  line->Ro = line->z0 = args[i++];
+  line->len         = args[i++];
+  line->w           = args[i++];
+  line->s           = args[i++];
+  line->subs->h     = args[i++];
+  line->l           = args[i++];
+  line->subs->tmet  = args[i++];
+  line->subs->rho   = args[i++];
+  line->subs->rough = args[i++];
+  line->subs->er    = args[i++];
+  line->subs->tand  = args[i++];
+  line->with_ground = args[i++];
+  line->freq        = args[i++];
+  flag              = args[i++];
+
+  /* run the calculation */
+  if( coplanar_syn(line, line->freq, flag) ) {
+    printf("%s", ERRMSG);
+  } else {
+
+    /* print the outputs */
+    printf("%g %g %g %g %g\n", line->w, line->s, line->subs->h,
+	   line->l, line->subs->er);
+  }
+
+  /* clean up */
+  coplanar_line_free(line);
+  
+  return;
+}
+
 /* 
  * [z0,k,z0e,z0o,kev,kodd,loss_ev,loss_odd, deltal_ev, deltal_odd] =
  *   coupled_microstrip_calc(w,s,h,l,tmet,rho,rough,er,tand,f);
@@ -536,6 +686,91 @@ static void exec_coupled_microstrip_syn(double *args)
   return;
 }
 
+/* 
+ * [z0,k,z0e,z0o,kev,kodd,loss_ev,loss_odd, deltal_ev, deltal_odd] =
+ *   coupled_stripline_calc(w,s,h,l,tmet,rho,rough,er,tand,f);
+ */
+static void exec_coupled_stripline_calc(double *args)
+{
+  /* our coupled_stripline for calculations */
+  coupled_stripline_line *line;
+  int i = 0;
+
+  /* create the line and fill in the parameters */
+  line = coupled_stripline_line_new();
+  line->w           = args[i++];
+  line->s           = args[i++];
+  line->subs->h     = args[i++];
+  line->l           = args[i++];
+  line->subs->tmet  = args[i++];
+  line->subs->rho   = args[i++];
+  line->subs->rough = args[i++];
+  line->subs->er    = args[i++];
+  line->subs->tand  = args[i++];
+  line->freq        = args[i++];
+
+  /* run the calculation */
+  if( coupled_stripline_calc(line, line->freq) ) {
+    printf("%s", ERRMSG);
+  } else { 
+  
+    /* print the outputs */
+    printf("%g %g %g %g %g %g %g %g\n", 
+	   line->z0, line->k,
+	   line->z0e, line->z0o, 
+	   line->loss_ev, line->loss_odd, 
+	   line->deltale, line->deltalo);
+  }
+
+  /* clean up */
+  coupled_stripline_line_free(line);
+}
+  
+/* 
+ * [w_out,s_out,l_out] = 
+ *   coupled_stripline_syn(z0,k,elen,w,s,h,l,tmet,rho,rough,er,tand,f,0);
+ * [w_out,s_out,l_out] = 
+ *   coupled_stripline_syn(z0e,z0o,elen,w,s,h,l,tmet,rho,rough,er,tand,f,1);
+ */
+static void exec_coupled_stripline_syn(double *args)
+{
+  /* our coupled_stripline for calculations */
+  coupled_stripline_line *line;
+  int i = 0;
+
+  /* create the line and fill in the parameters */
+  line = coupled_stripline_line_new();
+  line->z0 = line->z0e = args[i++];
+  line->k  = line->z0o = args[i++];
+  line->len         = args[i++];
+  line->w           = args[i++];
+  line->s           = args[i++];
+  line->subs->h     = args[i++];
+  line->l           = args[i++];
+  line->subs->tmet  = args[i++];
+  line->subs->rho   = args[i++];
+  line->subs->rough = args[i++];
+  line->subs->er    = args[i++];
+  line->subs->tand  = args[i++];
+  line->freq        = args[i++];
+  line->use_z0k     = !args[i++];
+
+  /* run the calculation */
+  if( coupled_stripline_syn(line, line->freq) ) {
+    printf("%s", ERRMSG);
+  } else { 
+  
+    /* print the outputs */
+    printf("%g %g %g\n", 
+	   line->w, line->s, line->l);
+  }
+
+  /* clean up */
+  coupled_stripline_line_free(line);
+  
+  return;
+}
+
 /*
  * [Ro, Xo ,keff,elen,loss,L,R,C,G] = 
  *  ic_microstrip_calc(w,l,tox,eox,h,es,sigmas,tmet,rho,rough,f);
@@ -650,7 +885,9 @@ static void exec_microstrip_calc(double *args)
     /* print the outputs */
     printf("%g %g %g %g %g %g %g %g %g %g %g %g \n", line->z0, line->keff,
 	   line->len, line->loss, line->Ls, line->Rs, line->Cs, line->Gs,
-      line->alpha_c, line->alpha_d, line->deltal, line->skindepth);
+	   line->alpha_c*20.0*log10(exp(1.0)), 
+	   line->alpha_d*20.0*log10(exp(1.0)),
+	   line->deltal, line->skindepth);
   }
 
   /* clean up */
@@ -702,6 +939,144 @@ static void exec_microstrip_syn(double *args)
   return;
 }
 
+/*
+ *  [Cs, Rs, Qs, Cp, Rp, Qp] = parallel_rc_p2s(Cp, Rp, Qp, freq, flag)
+ */
+static void exec_parallel_rc_p2s(double *args)
+{
+  parallel_rc *net;
+  int i = 0;
+
+  net = parallel_rc_new();
+  net->Cp = args[i++];
+  net->Rp = args[i++];
+  net->Qp = args[i++];
+  net->freq = args[i++];
+  net->use_Q = (int) rint(args[i++]);
+
+  net->series_to_parallel = 0;
+
+  /* run the calculation */
+  if(  parallel_rc_calc(net, net->freq) ) {
+    printf("%s", ERRMSG);
+  } else {
+    /* print the outputs */
+    printf("%g %g %g %g %g %g\n", 
+	   net->Cs, net->Rs, net->Qs,
+	   net->Cp, net->Rp, net->Qp);
+  }
+
+  /* clean up */
+  parallel_rc_free(net);
+  
+  return;
+}
+
+
+/*
+ *  [Cs, Rs, Qs, Cp, Rp, Qp] = parallel_rc_s2p(Cs, Rs, Qs, freq, flag)
+ */
+static void exec_parallel_rc_s2p(double *args)
+{
+  parallel_rc *net;
+  int i = 0;
+
+  net = parallel_rc_new();
+  net->Cs = args[i++];
+  net->Rs = args[i++];
+  net->Qs = args[i++];
+  net->freq = args[i++];
+  net->use_Q = (int) rint(args[i++]);
+
+  net->series_to_parallel = 1;
+
+  /* run the calculation */
+  if(  parallel_rc_calc(net, net->freq) ) {
+    printf("%s", ERRMSG);
+  } else {
+    /* print the outputs */
+    printf("%g %g %g %g %g %g\n", 
+	   net->Cs, net->Rs, net->Qs,
+	   net->Cp, net->Rp, net->Qp);
+  }
+
+  /* clean up */
+  parallel_rc_free(net);
+  
+  return;
+}
+
+
+
+/*
+ *  [Ls, Rs, Qs, Lp, Rp, Qp] = parallel_rl_p2s(Lp, Rp, Qp, freq, flag)
+ */
+static void exec_parallel_rl_p2s(double *args)
+{
+  parallel_rl *net;
+  int i = 0;
+
+  net = parallel_rl_new();
+  net->Lp = args[i++];
+  net->Rp = args[i++];
+  net->Qp = args[i++];
+  net->freq = args[i++];
+  net->use_Q = (int) rint(args[i++]);
+
+  net->series_to_parallel = 0;
+
+  /* run the calculation */
+  if(  parallel_rl_calc(net, net->freq) ) {
+    printf("%s", ERRMSG);
+  } else {
+    /* print the outputs */
+    printf("%g %g %g %g %g %g\n", 
+	   net->Ls, net->Rs, net->Qs,
+	   net->Lp, net->Rp, net->Qp);
+  }
+
+  /* clean up */
+  parallel_rl_free(net);
+  
+  return;
+}
+
+
+/*
+ *  [Ls, Rs, Qs, Lp, Rp, Qp] = parallel_rc_s2p(Ls, Rs, Qs, freq, flag)
+ */
+static void exec_parallel_rl_s2p(double *args)
+{
+  parallel_rl *net;
+  int i = 0;
+
+  net = parallel_rl_new();
+  net->Ls = args[i++];
+  net->Rs = args[i++];
+  net->Qs = args[i++];
+  net->freq = args[i++];
+  net->use_Q = (int) rint(args[i++]);
+
+  net->series_to_parallel = 1;
+
+  /* run the calculation */
+  if(  parallel_rl_calc(net, net->freq) ) {
+    printf("%s", ERRMSG);
+  } else {
+    /* print the outputs */
+    printf("%g %g %g %g %g %g\n", 
+	   net->Ls, net->Rs, net->Qs,
+	   net->Lp, net->Rp, net->Qp);
+  }
+
+  /* clean up */
+  parallel_rl_free(net);
+  
+  return;
+}
+
+
+
 /* 
  * [z0,loss,deltal] = 
  *   stripline_calc(w,h,l,tmet,rho,rough,er,tand,f);
